<?php
/**
* Plugin Name: Crew Manager
* File get-eventcrew-wp_crontask.php
* File Version 1.0.0 Beta
* Author: Bill Kneller
* Author URI: http://crew-mgr.com
* 5/16/2018 Rewritten to be called using functions from within Wordpress
* where cron triggers this file.
* This fixes headers already sent problem with previous approach.
* This mod also eliminates need for seperate Email Posts to Customer Plugin
* 5/7/2012 Added switch to turn on/off sending Crew Emails from admin panel
* 4/22/2018 made sure "Stay Ashore" gets email by removing
* AND cma.position_id !=$stay_ashore from crew query
* This is called by cron to get the list of crew members & ai1ec posts.
* 1.  Checks what ai1ec events are scheduled >= 36 to = 37 hours later
* 2.  Gets the post IDs for these events 
* 3.  Gets the users (crew members) associated with the found post IDs
* 4.  Formats an HTML email and does shorcodes
* 5.  Sends post as html email
* 6.  Send notification to crew admins if enabled.
**/
$debug="Yes";  // Set to "Yes" to turn on debug echo displays 
$display_email="";  // Set to "Yes" to turn on sample email when debug is "Yes" 
/** First load the Wordpress environment to use Wordpress functions ***/
$path = preg_replace('/wp-content.*$/','',__DIR__);
require_once($path.'wp-load.php');

/** Now execute the Crew Manager tasks triggered by wp-cron trigger ***/
event_crew_wp_cron($debug); // calls the function below that has the meat!

/** everything below contains the functions called above **/
function event_crew_wp_cron($debug){

$recipients = "";
// get the setting from Wordpress options table
global $crew_manager_options;
$crew_manager_options = get_option('crew_manager_settings');

$stay_ashore = get_position_id_number('Stay Ashore');
$hours_lower = $crew_manager_options['lead_time']; // start looking 36 hours in advance or as set in admin panel
$hours_upper = $hours_lower + 1;  // finish looking lower + 1 hour in advance

if ($debug=="Yes") echo "<b>Debug Displays enabled with $"."debug set to \"Yes\"</b><br>";
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
$cur_yr = date('Y'); // gets curent year for query
$cur_datetime = strtotime(date("Y-m-d H:i:s")); // gets curent datetime for query
$future_lower_limit = mktime(date('H')+$hours_lower,date('i'),date('s'),date('n'),date('j'),date('Y'));
$future_upper_limit = mktime(date('H')+$hours_upper,date('i'),date('s'),date('n'),date('j'),date('Y'));
if ($debug == "Yes") {
   echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Current Time: ".$cur_datetime."  ".date('D F jS, Y @ g:i:sa T',$cur_datetime)."<br>"; //debug
   echo "&nbsp;>= Lower Limit: ".$future_lower_limit."  ".date('D F jS, Y @ g:i:sa T',$future_lower_limit)."&nbsp;&nbsp;(".$hours_lower." hours)<br>"; //debug
   echo "&nbsp;&nbsp;&nbsp;&nbsp;< Upper Limit: ".$future_upper_limit."  ".date('D F jS, Y @ g:i:sa T',$future_upper_limit)."&nbsp;&nbsp;(".$hours_upper." hours)<br>"; //debug
}
$subject = "[boat] Reminder: ###POSTTITLE### [eventdate]";
$content = "Hello ###NAME###,<br><br>###POSTLINK-WITHTITLE###<br><br>###POSTFULL###<br>###POSTIMAGE###";

// first get the wp global and add prefix
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_ai1ec_instances  = $wpdb->prefix."ai1ec_event_instances";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_users  = $wpdb->prefix."users";
    $table_posts  = $wpdb->prefix."posts";
    $current_date = current_time( 'mysql' ); // uses Wordpress call

// ai1ec post query by time here
$eventquery = $wpdb->get_results("SELECT `p`.ID 'PostID', `e`.start 'DateTime' FROM `$table_ai1ec_events` `e`, `$table_ai1ec_instances` `i`, `$table_posts` `p` 
WHERE `e`.post_id = `p`.ID
AND `e`.post_id = `i`.post_id
AND `p`.post_status = 'publish'
AND FROM_UNIXTIME(`e`.start, '%Y') = '$cur_yr'
AND `e`.start >= '$future_lower_limit' 
AND `e`.start < '$future_upper_limit' 
GROUP BY `p`.ID
ORDER BY `e`.start
", ARRAY_A);
// iterate through the events to get the ai1ec post_id numbers
// var_dump($eventquery); // debug

foreach($eventquery as $erow)
{
$post_id = $erow['PostID'];
// if (!session_id())  session_start();  // allows saving variables between page submissions
$_SESSION['elp_post_id'] = $post_id; // passes to [crew] processing	


// Get crew members for selected post
// exclude not available and show available if position designated as 'Stay Ashore'
$crewquery = $wpdb->get_results("SELECT `u`.ID 'ID', `cma`.available 'Available'  FROM `$table_ai1ec_events` `e`, `$table_crewmgr_assigned` `cma`, `$table_users` `u`  
WHERE `e`.post_id = '$post_id' AND `cma`.ai1ec_post_id = '$post_id'
AND `u`.ID = `cma`.user_ID
AND `cma`.available < 3
ORDER BY `cma`.available, `u`.display_name
", ARRAY_A);

$i=0; // initialize number of messages sent counter
foreach($crewquery as $row)
{
// var_dump($row); // debug
	$i++;
	$user_id = $row['ID'];
	$user_info = get_userdata( $user_id );
	$to_email = $user_info->user_email;
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to = $to_name. " <".$to_email.">";
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
	send_formatted_email($user_id, $subject, $content, $post_id); // execute the send routine
} // end foreach($crewquery as $row)
if ($debug=="Yes") echo  $recipients . "<br>"; // debug
if ($debug=="Yes") echo "Post ID processed: ".$post_id."<br>"; // debug
global $crew_manager_options;
if ($debug=="Yes" && $crew_manager_options['stop_crew_email']==1) 
{ echo "<b>Sending Crew Emails turned on in Admin Panel</b><br>";} else
{ echo "<b>Sending Crew Emails turned off in Admin Panel</b><br>";}
$subject = "[boat] Reminder: ###POSTTITLE### [eventdate]";
$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "An event reminder was sent successfully to " . $i . $emails . ". Please find the details below<br><br>";

send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
}  // end foreach($eventquery as $erow)
return;
} // end function event_crew_wp_cron($debug)