<?php
/*
* Plugin Name: Crew Manager
* File functions.php
* File Version 1.1.0 Beta
* Author: Bill Kneller
* Author URI: http://crew-mgr.com

* Name: Functions Used by Other files
* for Crew Manager plugin - using shortcodes.
* This file also has houskeeping functions like
* adding login/logout to menu, redirect to home page
* on login/logout, add extra fields to user in WP Admin.
*
* 6/18/2018 added regatta dropdown for crew weight report
* 6/6/2018 added skipper email capability
* 5/24/2018 added Retired group for email lists & crew dropdown.  Removed wp_admin_hide since the Retired group handles this.  Added extra user profile fields.
* 5/23/2018 fixed spurious emails on non post updates (e.g. Graphene settings)
* 5/22/2018 Added "Cancel Event Immediately" button processing for [crew]
* 5/21/2018 Added Crew Email Optout visible to crew in profile if allowed in admin panel
* 5/19/2018 Updated all mail functions to remove ELP plugin
* 5/15/2018 Added extra user fields corecrew & allposts saved as user meta
*  added email post function (eliminate ELP plugin)   
* 5/6/2012 Added detection of race results posting to send email
* 5/1/2018 added shortcodes [boat], [boaturl] and [eventdate]
* 4/27/2018 changed login to allow redirect from [crew] also
* 4/22/2018 revised position dropdown to hide admin & Graphene hide
**/

/***************************
* function  ai1ec_save_post_id_on_update($post_id, $post, $update)
* This function is trigger on post update and writes the post_id 
* to database as a temporary save so it may be used to
* check if an ai1ec event has been updated with results data.
* This is passed to the email routine, then the temporary save is cleared
****************************/
 add_action( 'save_post', 'ai1ec_save_post_id_on_update', 10, 3);
function ai1ec_save_post_id_on_update($post_id, $post, $update )
{
$content_post = get_post($post_id);
$post_type = $content_post -> post_type;
$race_results=$race_results_link=$series_results=$series_results_link=$results_display=$series_display=$have_results="";
$series_display="";
$race_results = get_post_meta($post_id, 'race_results', false);
$race_results_link = get_post_meta($post_id, 'race_results_link', false);
$series_results = get_post_meta($post_id, 'series_results', false);
$series_results_link = get_post_meta($post_id, 'series_results_link', false);
	if ($race_results || $race_results_link || $series_results || $series_results_link) $have_results=1; //format results as text if set in meta for post

if ($post_type =='ai1ec_event' && 'publish' == get_post_status( $post_id ) && $have_results==1)
	{
	 update_option('crew_manager_ai1ec_post_id', $post_id); // save only if this is a published ai1ec post
	}
$post_id = get_option('crew_manager_ai1ec_post_id');
if ($post_id)
{
	crew_manager_send_results($post_id, $post="", $update=""  ); // email the results
	delete_option('crew_manager_ai1ec_post_id'); // clear after emails sent
} // endif $post_id
}
// end function  ai1ec_save_post_id_on_update


/** 
* function crew_manager_send_results($post_id, $post, $update )
* detects when race results posted on an event (post saved with meta) 
* then sends email to those who crewed with the results
*
**/

function crew_manager_send_results($post_id, $post, $update )
{
$race_results=$race_results_link=$series_results=$series_results_link=$results_display=$series_display="";
$series_display="";
$race_results = get_post_meta($post_id, 'race_results', false);
$race_results_link = get_post_meta($post_id, 'race_results_link', false);
$series_results = get_post_meta($post_id, 'series_results', false);
$series_results_link = get_post_meta($post_id, 'series_results_link', false);
if($race_results) $results_display="<font color=\"blue\"><b>Race Results:</b></font> ".$race_results[0]."&nbsp;&nbsp;"; //format results as text if set in meta for post
$results_formatted_link='<a href="'.$race_results_link[0].'" target=\"_blank\">'.$race_results[0].'</a>';
if($race_results && $race_results_link) $results_display="<font color=\"blue\"><b>Race Results:</b></font> ".$results_formatted_link."&nbsp;&nbsp;"; //format results as a link for post
$series_results = get_post_meta($post_id, 'series_results', false);
$series_results_link = get_post_meta($post_id, 'series_results_link', false);
if($series_results) $series_display="<font color=\"blue\"><b>Series Results:</b></font> ".$series_results[0]."&nbsp;&nbsp;"; //format results as text if set in meta for post
$series_results_formatted_link='<a href="'.$series_results_link[0].'" target=\"_blank\">'.$series_results[0].'</a>';
if($series_results && $series_results_link) $series_display="<font color=\"blue\"><b>Series Results:</b></font> ".$series_results_formatted_link."&nbsp;&nbsp;"; //format results as a link for post
$title = get_the_title( $post_id );
$event_date = get_event_start_date($post_id);
$event_date = (substr($event_date, 0, strpos($event_date, '@')));
$Event_URL='<a href="'.get_permalink( $post_id ).'">'.get_the_title( $post_id ).'</a>';
$subject = get_bloginfo( 'name' ) . " Race Results Posted for ". $title;
$body = "The following results were posted by " . get_bloginfo( 'name' )  . " for the " . $Event_URL  . " on " . $event_date. "<br>";
$body .=$results_display . $series_display . "<br>"; //display results if available
$subject = str_replace("&#8211;", "-", $subject); // puts dash in for ascii code
$body .= "<br>The following crew participated in this event:";
global $wpdb;
global $crew_manager_options;
$hide = "";
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
    $table_users  = $wpdb->prefix."users";
if ($crew_manager_options['crew_hide']==1) $hide="AND cma.available !=3";
$crewquery = $wpdb->get_results("SELECT u.display_name 'Name', u.ID 'ID', cmp.position 'Position', cmp.position_id 'PosID', cma.available 'Available', cma.id 'AvailID', cma.assignment 'Assigned', e.post_id 'PostID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma, $table_crewmgr_position cmp, $table_users u  
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND cma.position_id = cmp.position_id
AND (u.ID = cma.user_ID
$hide
AND (u.ID = cma.user_ID AND cmp.position != 'Stay Ashore')
AND (u.ID = cma.user_ID AND cmp.position != 'Not Assigned')
AND (u.ID = cma.user_ID AND cma.available !=3)
AND (u.ID = cma.user_ID AND cma.available !=0)
AND (u.ID = cma.user_ID AND cma.available !=''))

ORDER BY cma.available, u.display_name
", ARRAY_A);
$body .="<br>"; // insert line before adding crew manager content
    $body .="<table width=\"30%\"  border=\"1\" cellspacing=\"0\" cellpadding=\"0\">";
    $body .="<tr><td><b>Name</b></td><td><b>Position</b></td><td width=\"20%\"><b>Assignment</b></td></tr>";
$yes_count=0;
$maybe_count=0;
$to = $recipients = "";
$i=0;

foreach($crewquery as $row) // this query iteration formats message with crew
{
    // display each $row from query here.
	$user_info = get_userdata( $row['ID'] );
     $bgcolor="#ffffff"; // white  
     if($row['Available']=="3" || $row['Position']=="Stay Ashore") $bgcolor="#ffccff"; // pink  
     if($row['Available']=="1" && $row['Position']=="Standby Crew") $bgcolor="#ffff99"; // yellow 
     if($row['Available']=="2") $bgcolor="#ffff99"; // yellow
     if($row['Available']=="1" && ($row['Position']!="Not Assigned" && $row['Position']!="Standby Crew")) $bgcolor="#C2FFC2"; // green
     if(($row['Available']=="1" || $row['Available']=="2") && $row['Position']=="Not Assigned") $bgcolor="#ffffff"; // white
     if($row['Position']=="Stay Ashore") $bgcolor="#ffccff"; // pink  
    $body .= "\n<tr><td bgcolor=$bgcolor>". $user_info->first_name." ".$user_info->last_name . "</td><td bgcolor=$bgcolor>".$colordot." ".$row['Position']."</td><td bgcolor=$bgcolor>".$row['Assigned']."</td></tr>";
if ($bgcolor=="#C2FFC2")++$yes_count; // increments for yes (green)
if ($bgcolor=="#ffff99")++$maybe_count; // increments for maybe (yellow)
if ($bgcolor=="#ffffff")++$maybe_count; // increments for maybe (white)
$i++; // increments email counter
$user_info = get_userdata( $row['ID'] );
$to_email = $user_info->user_email;
$crew_name = $user_info->first_name." ".$user_info->last_name;
$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $crew_name . " [" . $to_email . "]<br>";
}// end foreach crewquery to format message
$total_count = $yes_count + $maybe_count;
    $body .="<td colspan=\"4\" align=\"center\"><b>Total Crew </b>".$total_count ."<b> = Confirmed (</b>".$yes_count."<b>) + Maybe (</b>".$maybe_count."<b>)</b></td>";
    $body .="</table>";
global $crew_manager_options;
$user_info = get_userdata( $crew_manager_options['skipper'] );
$from_email = $user_info->user_email;
$skipper_name = $user_info->first_name." ".$user_info->last_name;
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = "From: ".$skipper_name." <".$from_email.">";
foreach($crewquery as $row) // this query iteration sends the messag
{
	$user_info = get_userdata( $row['ID'] );
	$to_email = $user_info->user_email;
	$crew_name = $user_info->first_name." ".$user_info->last_name;
	$to =$crew_name." <".$to_email.">, ";
	if($crew_manager_options['stop_crew_email']==1) wp_mail( $to, $subject, $body, $headers ); // sends html formatted email if enabled in admin panel
}// end foreach crewquery to send crew message
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = 'From: Crew Manager Administrator  <' .  get_bloginfo("admin_email") .'>';

$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "Event results were sent to " . $i . $emails . ". Please find the details below<br><br>";
if($crew_manager_options['stop_elp_notifications']==1) send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
}
// /** end function crew_manager_send_results **/

/** removes admin bar search when logged in **/
function remove_admin_menu_bar_items ($wp_toolbar) {
//    $wp_toolbar->remove_node( 'my-sites' );
//    $wp_toolbar->remove_node( 'wp-logo' );
//    $wp_toolbar->remove_node( 'new-content' );
//    $wp_toolbar->remove_node( 'view' );
    $wp_toolbar->remove_node( 'search' );  // remove the search element
    return $wp_toolbar;
}
add_filter( 'admin_bar_menu', 'remove_admin_menu_bar_items' );


/** function add_login_logout_link ******** 
* this adds a login / logout button to the menu 
**/
error_reporting(E_ALL & ~E_NOTICE); // turn off error notices
add_filter('wp_nav_menu_items', 'add_login_logout_link', 10, 2);
function add_login_logout_link($items, $args) {
      if (is_user_logged_in()) {
         $items .= '<li class="right"><a href="'. wp_logout_url() .'">'. __("Log Out") .'</a></li>';
      } else {
         $items .= '<li class="right"><a href="'. wp_login_url(home_url()) .'">'. __("Log In") .'</a></li>';
      }

    return $items;
}
// /** end function add_login_logout_link ******** 

add_action('wp_logout','auto_redirect_after_logout');
function auto_redirect_after_logout(){
wp_redirect( home_url() );
exit();
}
// end of logout redirect function


/** adds function my_show_extra_profile_fields( $user )
*   for custom fields added to the user profile and stored in meta 
* https://wordpress.stackexchange.com/questions/214719/how-do-i-add-a-field-on-the-users-profile-for-example-country-age-etc
**/
add_action( 'show_user_profile', 'my_show_extra_profile_fields' );
add_action( 'edit_user_profile', 'my_show_extra_profile_fields' );

function my_show_extra_profile_fields( $user ) {
global $crew_manager_options;
 ?>
	<h3>Extra profile information</h3>
	<table class="form-table">
		<tr>
			<th><label for="mobile">Mobile Phone</label></th>
			<td>
				<input type="text" name="mobile" id="mobile" value="<?php echo esc_attr( get_the_author_meta( 'mobile', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description">Please enter your Mobile Phone number.</span>
			</td>
		</tr>
		<tr>
			<th><label for="shirt_size">Shirt Size</label></th>
			<td>
           <?php 
           //get dropdown saved value
           $selected = get_the_author_meta('shirt_size', $user->ID);
           ?>
				 <select name="shirt_size" id="shirt_size">
                    <option value="0" <?php echo ($selected == "0")?  'selected="selected"' : '' ?>>Select a Shirt Size</option>
                    <option value="1" <?php echo ($selected == "1")?  'selected="selected"' : '' ?>>Mens - S</option>
                    <option value="2" <?php echo ($selected == "2")?  'selected="selected"' : '' ?>>Mens - M</option>
                    <option value="3" <?php echo ($selected == "3")?  'selected="selected"' : '' ?>>Mens - L</option>
                    <option value="4" <?php echo ($selected == "4")?  'selected="selected"' : '' ?>>Mens - XL</option>
                    <option value="5" <?php echo ($selected == "5")?  'selected="selected"' : '' ?>>Mens - XXL</option>
                    <option value="6" <?php echo ($selected == "6")?  'selected="selected"' : '' ?>>Womens - Petite</option>
                    <option value="7" <?php echo ($selected == "7")?  'selected="selected"' : '' ?>>Womens - Small</option>
                    <option value="8" <?php echo ($selected == "8")?  'selected="selected"' : '' ?>>Womens - Medium</option>
                    <option value="9" <?php echo ($selected == "9")?  'selected="selected"' : '' ?>>Womens - Large</option>
                    <option value="10" <?php echo ($selected == "10")?  'selected="selected"' : '' ?>>Womens - Extra Large</option>
                </select>
<br />
				<span class="description">Please select your shirt size.</span>
			</td>
		</tr>
		<tr>
			<th><label for="weight">Weight in lbs.</label></th>
			<td>
				<input type="number" name="weight" id="weight"  value="<?php echo esc_attr( get_the_author_meta( 'weight', $user->ID ) ); ?>"  /><br />
				<span class="description">Please enter your weight in pounds.</span>
			</td>
		</tr>
		<tr>
			<th><label for="isaf_number">World Sailing Sailor ID</label></th>
			<td>
				<input type="text" name="isaf_number" id="isaf_number" size="7" value="<?php echo esc_attr( get_the_author_meta( 'isaf_number', $user->ID ) ); ?>"  /><br />
				<span class="description">Please enter your World Sailing (ISAF) Sailor ID.</span>
			</td>
		</tr>
		<tr>
			<th><label for="isaf_classification">World Sailing Sailor Classification</label></th>
			<td>
           <?php 
           //get dropdown saved value
           $selected = get_the_author_meta('isaf_classification', $user->ID);
           ?>

				<select name="isaf_classification" id="isaf_classification">
                    <option value="0" <?php echo ($selected == "0")?  'selected="selected"' : '' ?>>Select Classification Status</option>
                    <option value="1" <?php echo ($selected == "1")?  'selected="selected"' : '' ?>>Group 1 (Amateur)</option>
                    <option value="3" <?php echo ($selected == "3")?  'selected="selected"' : '' ?>>Group 3 (Professional)</option>
                </select>
<br />
				<span class="description">Please select your World Sailing (ISAF) Sailor Classification.</span>
			</td>
		</tr>
		<tr>
			<th><label for="ussailing">US Sailing Membership Number</label></th>
			<td>
				<input type="text" name="ussailing" id="ussailing" size="7" value="<?php echo esc_attr( get_the_author_meta( 'ussailing', $user->ID ) ); ?>"  /><br />
				<span class="description">Please enter your US Sailing Membership Number.</span>
			</td>
		</tr>
		<tr>
	<?php /** show email list check boxes only for crew admins ***/ 
	if( current_user_can( 'create_users' ) )
	{ ?>
		<tr>
			<th><label for="corecrew">Include on Core Crew Email List</label></th>
			<td>
				<input type="checkbox" name="corecrew" id="corecrew" value="yes" <?php if (esc_attr( get_the_author_meta( "corecrew", $user->ID )) == "yes") echo "checked"; ?> /><label for="corecrew"><?php _e("&nbsp;Check the box for user to be included on Core Crew Email List."); ?></label><br /><br />
			</td>
		</tr>
<?php } ?>
	<?php /** show allpost email optout check boxes for crew admins and a user if allowed in admin panel***/ 

	if( current_user_can( 'create_users' ) || $crew_manager_options['crew_email_allow_optout']==1)
	{ ?>
		<tr>
			<th><label for="allposts">Include on All Posts Email List</label></th>
			<td>
				<input type="checkbox" name="allposts" id="allposts" value="yes" <?php if (esc_attr( get_the_author_meta( "allposts", $user->ID )) == "yes") echo "checked"; ?> /><label for="allposts"><?php _e("&nbsp;Uncheck box to Optout of new posts and comment Emails. <br><em>Crew listed for an event will always get event reminders and associated results.</em>"); ?></label><br /><br />
			</td>
		</tr>
<?php } ?>

	</table>
<?php }

/** End of function my_show_extra_profile_fields  **/

/** This function my_save_extra_profile_fields( $user )
*   saves the custom fields to the user profile as meta 
**/

add_action( 'personal_options_update', 'my_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'my_save_extra_profile_fields' );
add_action( "user_new_form", 'my_show_extra_profile_fields' );

function my_save_extra_profile_fields( $user_id ) {
	if ( !current_user_can( 'edit_user', $user_id ) )
		return false;
	update_usermeta( $user_id, 'mobile', $_POST['mobile'] );
	if ( current_user_can( 'create_users', $user_id ) )
	{
	update_usermeta( $user_id, 'allposts', $_POST['allposts'] );
	update_usermeta( $user_id, 'corecrew', $_POST['corecrew'] );
	update_usermeta( $user_id, 'shirt_size', $_POST['shirt_size'] );
	update_usermeta( $user_id, 'weight', $_POST['weight'] );
	update_usermeta( $user_id, 'isaf_number', $_POST['isaf_number'] );
	update_usermeta( $user_id, 'isaf_classification', $_POST['isaf_classification'] );
	update_usermeta( $user_id, 'ussailing', $_POST['ussailing'] );
	}
}
/** End of function my_save_extra_profile_fields  **/
add_action('user_register', 'my_save_extra_profile_fields');
add_action('profile_update', 'my_save_extra_profile_fields');



/**
 * Function to populate dropdown box with registered users 
 *
 * Output is an array variable so that the user data may be displayed
**/
function get_registered_users_dropdown($user_ID)
{
    $dropdown = "<select name='crew' size='1' id='crew'>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
global $wpdb;
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'last_name',
		'order' => 'ASC',
	];
	$user_query = new WP_User_Query( $user_args );
	$wp_users = $user_query->get_results();

	foreach( $wp_users as $wp_user ){
			$retired_hide = "";
			$user_info = get_userdata( $wp_user->ID );
			$user_meta = get_user_meta( $wp_user->ID );
			$graphene_author_hide_email = $user_meta['graphene_author_hide_email'][0];
			if(esc_attr(get_the_author_meta( 'retired', $wp_user->ID )) == "yes") $retired_hide = "hide";
			$crew_mgr_admin_hide = "";
			$admin_rights = user_can( $user_info->ID, 'activate_plugins' );

			IF ( !$retired_hide && !$graphene_author_hide_email ){
		    $dropdown .= "<option value=\"". $user_info->ID . "\"";
		    if ($user_ID==$user_info->ID) $dropdown .= " selected ";
		    $dropdown .= ">";
		    $user_firstname = $user_info->first_name;
		    $user_lastname = $user_info->last_name;
		    $dropdown .= $user_info->display_name." -> ".$user_firstname." ".$user_lastname."</option>";
          } ELSE
          { // skip if admin = 1
          }

	} // end foreach
   $dropdown .= "</select>";
return $dropdown;
}
//End function get_registered_users_dropdown / 


/**
 * Function availability_insert_or_update for database table crewmgr_assigned
 * on submission from crew availability page
**/
function availability_insert_or_update($ai1ec_post_id, $user_ID, $available, $position_id, $assigned_value)
{

//        echo "<p>Dump a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assigned: ". $assigned_value."</p>"; //debug
// *bypass* first see if record should be bypassed if no availability
if($available != 0){
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
$record_check = $wpdb->get_var("SELECT COUNT(id) FROM $table_crewmgr_assigned
WHERE ai1ec_post_id = $ai1ec_post_id
AND user_ID = $user_ID;"); //record is NULL if not in database so insert
    if ($record_check == 0){
// record not found so insert new record
    if ($position_id == 0)$position_id=get_position_id_number("Not Assigned");// force Not Assigned if no selection
//        echo "<p>Insert a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assignment: ". $assigned_value."</p>"; //debug
 //debug1 start comment out query
    $wpdb->insert($table_crewmgr_assigned, array(
        'ai1ec_post_id' => $ai1ec_post_id,
        'user_ID' => $user_ID,
        'available' => $available, 
        'position_id' => $position_id,
        'assignment' => $assigned_value
    ));
 //debug1 end
    } ELSE {
// record found so update record
//        echo "<p>Update a Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID." Available: ". $available." Position ID: ".$position_id." Assignment: ". $assigned_value."</p>"; //debug
 //debug2 start comment out query
        $wpdb->query("UPDATE $table_crewmgr_assigned SET available='$available', position_id='$position_id', assignment= '$assigned_value' WHERE ai1ec_post_id = '$ai1ec_post_id' AND user_ID = '$user_ID'");
  //debug2 end
    }
// echo "<p>Record: " . $record_check . "  Post: ". $ai1ec_post_id. "  User: ". $user_ID."</p>";
}  //*bypass* endif 
}
//End function availability_insert_or_update / 

/**
 * Function load_assignment_text_box to create text box and display
 * previously saved text, if there was any.
 * Array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_assignment_text($assignment_in, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.assignment AS  'Assigned', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
	$avail_index=$ai1ec_post_id;
	$assignment=$row['Assigned'];
}
$avail_index=$ai1ec_post_id;
    $text = $assignment;
return $text;
}
//End function load_assignment_text / 

/**
 * Function load_assignment_text_box to create text box and display previously saved
 * text, if there was any
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_assignment_text_box($assignment_in, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
	global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

	$query = $wpdb->get_results("SELECT cma.assignment AS  'Assigned', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
	WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
	AND cma.user_ID = $user_ID
	", ARRAY_A);
foreach($query as $row)
{
	$avail_index=$ai1ec_post_id;
	$assignment="";
	if (isset($row['Assigned'])) $assignment=$row['Assigned'];
}
$avail_index=$ai1ec_post_id;

    $textbox = "<input type='textarea' name='assigned[".$ai1ec_post_id."-".$user_ID."]' id='assigned[".$ai1ec_post_id."-".$user_ID."]'  size='30' maxlength='42' value='$assignment' />";

return $textbox;
}
//End function load_assignment_text_box / 

/**
 * Function load_available_dropdown to populate dropdown box with availability
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function load_available_dropdown($available, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available AS  'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
	$avail_index=$ai1ec_post_id;
	$available=$row['Available'];
}
$avail_index=$ai1ec_post_id;

    $dropdown = "<select name='available[".$ai1ec_post_id."-".$user_ID."]' size='1' id='available[".$ai1ec_post_id."-".$user_ID."]'>";
    $dropdown .= "<option value=0>-- Select Availability --</option>";
    $dropdown .= "<option ";
    if ($available==1 ) $dropdown .= "selected ";
    $dropdown .= "value=1>Yes</option>";
    $dropdown .= "<option ";
    if ($available==2 ) $dropdown .= "selected ";
    $dropdown .= "value=2>Maybe</option>";
    $dropdown .= "<option ";
    if ($available==3 ) $dropdown .= "selected ";
    $dropdown .= "value=3>No</option>";
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_available_dropdown / 

/**
 * Function load_year_dropdown to populate dropdown box 
 * Looks at ai1ec events for oldest entry and sets that year
 * as earliest to show in the year dropdown - defaults to
 * current year
**/
function load_year_dropdown($query_yr)
{
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT min(start) FROM $table_ai1ec_events"); // gets oldest event timestamp
$oldest_year = date('Y', $timestamp); // extracts the year
$cur_yr = date('Y'); // gets curent year for query
if (!$query_yr) $query_yr = $cur_yr;
    $dropdown = "<select name='query_yr' size='1' id='query_yr'>";
$counter = $cur_yr;	
//echo "query_yr: ".$query_yr. "  counter: ".$counter."<br>"; //debug
while ($oldest_year <= $counter) { 
    $dropdown .= "<option ";
    if ($query_yr==$counter) $dropdown .= "selected ";
    $dropdown .= "value=$counter>$counter</option>";
$counter--;
} // end while counter
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_year_dropdown / 

/**
 * Function provides initial dropdown value to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function initial_dropdown_value($available, $avail_index, $user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$ai1ec_post_id;}
    if ($row['Available']>>0){$available=$row['Available'];} 
    ELSE {$avail_index=$ai1ec_post_id;}
}
    $dropdown = $available;
return $dropdown;
}
//End function initial_dropdown_value / 

/**
 * Function gets available numeric value to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * array Key is $avail_index if status already set, otherwise $ai1ec_post_id 
**/
function get_available_value($user_ID, $ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $ai1ec_post_id AND cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['Available']>>0){$available=$row['Available'];} 
    ELSE {$avail_index=$ai1ec_post_id; }
}
$avail_val = "";
if (!empty($available[0])) $avail_val = $available[0];
return $avail_val;

}
//End function get_available_value / 

/**
 * Function get_available_text provides available lookup as text to display 
 * 0 or null = No Input
 * 1 = Yes
 * 2 = Maybe
 * 3 = No
 * input is $avail_index 
**/
function get_available_text($avail_index)
{
$avail_text = "No Input";
if ($avail_index == 1) $avail_text = "Yes";
if ($avail_index == 2) $avail_text = "Maybe";
if ($avail_index == 3) $avail_text = "No";
return $avail_text;
}
//End function get_available_text / 

/**
 * Function get_event_start_location to display in crew box
 * for reminder emails
 * Output is html formatted text using $ai1ec_post_id as key for lookup
**/
function get_event_start_location($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$query = $wpdb->get_results("SELECT e.start 'Start', e.venue 'Location'  FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
global $crew_manager_options;
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", $row['Start']); 

$text = "<h4>Be at ". $row['Location'] . " - " . $event_date ." @ ". $event_time ."</h4>";
} // end foreach
return $text;
}
//End function get_event_start_location / 

function get_event_start_date($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$query = $wpdb->get_results("SELECT e.start 'Start'FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", $row['Start']); 
$text = $event_date ." @ ". $event_time ;
} // end foreach
return $text;
}
//End function get_event_start_date / 

function get_event_start_date_no_correction($ai1ec_post_id)
{
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
$query = $wpdb->get_results("SELECT e.start 'Start'FROM $table_ai1ec_events e
WHERE e.post_id = $ai1ec_post_id
", ARRAY_A);
foreach($query as $row)
{
     $event_date=date("D F jS ", $row['Start']);
     $event_time=date("g:iA", ($row['Start'])); //don't adjust UTC to Local
$text = $event_date ." @ ". $event_time ;
} // end foreach
return $text;
}
//End function get_event_start_date_no_correction / 


/**
 * Function to get assigned position for crew availability matrix 
 * Pulls stored value from database and returns "Not Assigned" if not found
**/
function get_position($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";

$position = $wpdb->get_row("SELECT cmp.position as 'Position' FROM $table_crewmgr_position cmp, $table_crewmgr_assigned cma 
WHERE cma.ai1ec_post_id = $ai1ec_post_id
AND cma.user_ID  = $user_ID
AND cma.position_id = cmp.position_id
");
if ($wpdb->last_error) $pos = "Not Assigned";
$pos = $position->Position;
if (!$pos) $pos = "Not Assigned";
return $pos;
}
//End function get_position  


/**
 * Function to get position_id knowing user and post ID
 * Pulls stored value from database 
**/
function get_position_id($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$position_id = $wpdb->get_row("SELECT position_id as 'PosID' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$pos_id = "";
if ($position_id) $pos_id = $position_id->PosID; 
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  pos_id: ".$pos_id."<br>"; // debug
return $pos_id;
}
//End function get_position_id  

/**
 * Function to get_assigned_text knowing user and post ID
 * Pulls stored value from database 
**/
function get_assigned_text($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$position_id = $wpdb->get_row("SELECT assignment as 'Assigned' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$assigned_text = "";
if ($position_id) $assigned_text = $position_id->Assigned;
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  assigned_text: ".$assigned_text."<br>"; // debug
return $assigned_text;
}
//End function get_assigned_text 

/**
 * Function to get_available_id knowing user and post ID
 * Pulls stored value from database 
**/
function get_available_id($user_ID, $ai1ec_post_id)
{
global $wpdb;
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";

$available_id = $wpdb->get_row("SELECT available as 'Available' FROM $table_crewmgr_assigned 
WHERE user_ID = $user_ID AND ai1ec_post_id = $ai1ec_post_id
");
$available = $available_id->Available;
// echo "user_ID: ".$user_ID."  ai1ec_post_id: ".$ai1ec_post_id."  available: ".$available."<br>"; // debug
return $available;
}
//End function get_available_id 

/**
 * Function to populate dropdown box with crew positions 
 * The position descriptions are stored in table wp_crewmgr_position
 * Important values for position include
 * position = "Not Assigned" => default
 * position = "Stay Ashore" => marks displayed row in red
 * position = "Standby Crew" => marks displayed row in yellow
 * availability = 3 => "Not Available"
 *
 * Input parameters are setup so a unique event and user, with a previously
 * stored position if it was saved.
 *
 * Output is an array variable so that the position may be identified with the
 * unique event and user for saving in the database
**/
function load_position_dropdown($post_id, $user_ID, $avail_index)
{
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID', cma.position_id 'Position'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$post_id;}
    if ($row['Position']>>0){$position_id=$row['Position'];} 
    ELSE {$avail_index=$post_id;}
}
//End getting initial_position dropdown_value / 

$query = $wpdb->get_results("SELECT * FROM $table_crewmgr_position 
					ORDER BY position", ARRAY_A);
    $dropdown = "<select name='position[".$post_id."-".$user_ID."]' size='1' id='position[".$post_id."-".$user_ID."]'>";
    $dropdown .= "<option value='0'>-- Select a Position --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["position_id"] . "\"";
	if ($myrow["position_id"]==$position_id) {
    $dropdown .= " SELECTED>";
	   $found = 1;
	   } else {
    $dropdown .= ">";
	   }
    $dropdown .= $myrow["position"]."</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_position_dropdown / 

/**
 * Function to populate text with crew positions 
 * Input parameters are setup so a unique event and user, with a previously
 * stored position if it was saved.
 *
 * Output is single line of text
**/
function load_position_text($post_id, $user_ID, $avail_index)
{
$current_user = wp_get_current_user(); // gets user logged in
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
    $table_users  = $wpdb->prefix."users";

$query = $wpdb->get_results("SELECT cma.available 'Available', cma.id 'AvailID', cma.position_id 'Position'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND cma.user_ID = $user_ID
", ARRAY_A);
foreach($query as $row)
{
    if ($row['AvailID']>>0){$avail_index=$row['AvailID'];} 
    ELSE {$avail_index=$post_id;}
    if ($row['Position']>>0){$position_id=$row['Position'];} 
    ELSE {$avail_index=$post_id;}
}
//End getting load_position_text / 

$crewquery = $wpdb->get_results("SELECT u.display_name 'Name', u.ID 'ID', cmp.position 'Position', cmp.position_id 'PosID', cma.available 'Available', cma.id 'AvailID', cma.assignment 'Assigned'  FROM $table_ai1ec_events e, $table_crewmgr_assigned cma, $table_crewmgr_position cmp, $table_users u  
WHERE e.post_id = $post_id AND cma.ai1ec_post_id = $post_id
AND u.ID = cma.user_ID
AND u.ID = $user_ID
AND cma.position_id = cmp.position_id
ORDER BY cma.available, u.display_name
", ARRAY_A);
	foreach($crewquery as $row)
	{
		$position_text=$row['Position'];
	}
return $position_text;
}
//End function load_position_text / 

/**
* This function gets the ai1ec post and checks for [crew] shortcode.
* If it isn't, the post content is appended with [crew]
**/
 add_action( 'save_post', 'update_ai1ec_post_with_crew_shortcode' ); // trigger on post published
function update_ai1ec_post_with_crew_shortcode($post_id){
$content_post = get_post($post_id);
$post_type = $content_post -> post_type; 
	if ($post_type == 'ai1ec_event' ){ // check if this is ai1ec post
$content = $content_post -> post_content;
		if (strpos($content , '[crew]' ) !== false) { 
		} ELSE { // [crew] found
			$content .="
[crew]";
			$post = array(
			  'ID' => $post_id,
			  'post_content' => $content,
			); // array end
			global $wpdb;
		    $table_posts  = $wpdb->prefix."posts";
	        $wpdb->query("UPDATE $table_posts SET post_content='$content' WHERE ID = '$post_id' AND (post_status = 'publish' OR post_status = 'draft')");
		} // endif looking for strpos [crew]
	} // endif looking for ai1ec_event
}
// End function update_ai1ec_post_with_crew_shortcode /

// This function adds the current date to a post [date] shortcode
function displaydate(){
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
    return date('F jS, Y');
}
add_shortcode( 'date', 'displaydate' );
// End function to add the current date to a post

/**
 * Inserts [crew] shortcode for AI1EC Post content
 * this is commented out until I figure out how to put in ai1ec summaries
 * when looking at agenda view

function add_crew_shortcode_ai1ec($content){
  global $post;
  if( ! $post instanceof WP_Post ) return $content;

  switch( $post->post_type ) {
    case 'ai1ec_event':
      return $content.'[crew]';
    default:
      return $content;
  }
}

add_filter( 'the_content', 'add_crew_shortcode_ai1ec' );
// end of add_crew_shortcode_ai1ec ***************************
**/

/**********************************************************
* Kneller added DTG display in Upcoming Events Widget title 
*
* This function automatically prefixes posts with the [dtg][/dtg] shortcode
* So they are displayed with the days to go in the Upcoming Event widget
* Requires /wp-content/plugins/all-in-one-event-calendar/app/view/calendar/view/abstract.php
* be modified to apply the filter 'the_title_dtg'
***********************************************************/

function show_dtg($title) {

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event

$query_id = $wpdb->get_var("SELECT post_id FROM wp_ai1ec_events WHERE post_id = $postid");

	if($post_id=$query_id) {

		$title = '[dtg][/dtg]- '.$title; // this was $title

	}

	return $title;  // this was $title

}

add_filter( 'the_title_dtg', 'show_dtg' );

/**********************************************************
* This function show_cdt($content) automatically prefixes ai1ec content 
* with the [cdt][/cdt] shortcode
* So they are displayed with the days to go when the event is opened
***********************************************************/

function show_cdt($content) {

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
$query_id = $wpdb->get_var("SELECT post_id FROM $table_ai1ec_events WHERE post_id = $postid ");

	if($post_id=$query_id) {

		$content = '<h3>[cdt][/cdt]</h3>'.$content;

	}
	return $content;
}

add_filter( 'the_content', 'show_cdt' );


/*******************************************************
 * function content_countdown($atts, $content = null) 
* Inserts CDT shortcode for longer text "XX days until event" to use to
* display for AI1EC Event Posts
* http://wpsnipp.com/index.php/functions-php/countdown-timer-shortcode-display-content-after-specified-date/
***********************************************************/
function content_countdown($atts, $content = null){

// This section gets the Unix timestamp stored for the event and converts to month, day and year

// Get the start date data from the ai1ec_events table in the Wordpress database.

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT start FROM $table_ai1ec_events WHERE post_id = $postid");
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local

$month = date('m', $timestamp); // 1-12

$day = date('d', $timestamp); // 1-31

$year = date('Y', $timestamp); // 4 digit year

global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
    $remain = ceil((mktime( 0,0,0,(int)$month,(int)$day,(int)$year) - time())/86400);

    if( $remain > 1 ){

        return $daysremain = "<div class=\"event\"><b>$remain</b> days until this event</div>";

    }else if($remain == 1 ){

        return $daysremain = "<div class=\"event\"><b>Tomorrow!</b></div>";

    }else{

        return $content;

    }

}

add_shortcode('cdt', 'content_countdown');

// end of CDT shortcode **********************************



/************************************************************
* function content_dtg($atts, $content = null) Inserts DTG shortcode for
* shorter text "XX days" to use to display for AI1EC Posts
**************************************************************/
function content_dtg($atts, $content = null){

// This section gets the Unix timestamp stored for the event and converts to month, day and year

// Get the start date data from the ai1ec_events table in the Wordpress database.

global $wpdb;

$postid = get_the_ID(); // gets the current post ID associated with the event
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";

$timestamp = $wpdb->get_var("SELECT start FROM $table_ai1ec_events WHERE post_id = $postid");
global $crew_manager_options; // allows global [time_offset] and 
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
$month = date('m', $timestamp); // 1-12

$day = date('d', $timestamp); // 1-31

$year = date('Y', $timestamp); // 4 digit year
    $remain = ceil((mktime( 0,0,0,(int)$month,(int)$day,(int)$year) - time())/86400);

    if( $remain > 1 ){

        return $daysremain = "in $remain days";

    }else if($remain == 1 ){

        return $daysremain = "Tomorrow! ";

    }else{

        return $content;

    }

}

add_shortcode('dtg', 'content_dtg');

// end of DTG shortcode ***************************


/******************************************************************
 * function content_boat($atts, $content = null) Inserts name of boat
 * from site name as shortcode [boat]
*******************************************************************/
function content_boat($atts, $content = null){
$content = get_bloginfo( 'name' );
return $content;
}
add_shortcode('boat', 'content_boat');
// end of boat shortcode ***************************

/*******************************************************************
* function content_boaturl($atts, $content = null) Inserts url of boat
* website as shortcode [boaturl]
*********************************************************************/
function content_boaturl($atts, $content = null){
$content = "<a href=\"". home_url() ."\">". get_bloginfo( 'name' ) ."</a>";
return $content;
}
add_shortcode('boaturl', 'content_boaturl');
// end of boaturl shortcode ***************************


/******************************************************************
* function content_eventdate($atts, $content = null) Inserts event 
*start date & time for ELP event notification
*******************************************************************/
function content_eventdate($atts, $content = null){

$postid = get_the_ID(); // gets the current post ID associated with the event
if(!$postid) $postid = $_SESSION['elp_post_id']; // if no post ID get the id from sending newsletter process
$content = get_event_start_date($postid);
return $content;
}
add_shortcode('eventdate', 'content_eventdate');
// end of eventdate shortcode ***************************



/******************************************************************
* function get_user_email($user_id) to get email address of a user given the ID 
* 
* Output is single line of text
********************************************************************/

function get_user_email($user_id){

  $user_info = get_userdata($user_id);
  $email_text = $user_info->user_email;
return $email_text;
}
// end of get_user_email ***************************

/****************************************************************
* Function get_position_id_number($position) to get the position_id 
* given the position as text
* 
* Output is a number
******************************************************************/
function get_position_id_number($position){
global $wpdb;
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";

$query = $wpdb->get_results("SELECT cmp.position_id 'PositionID' FROM $table_crewmgr_position cmp
WHERE cmp.position = '$position'
", ARRAY_A);
foreach($query as $row)
{
    if ($row['PositionID']>>0)$PositionID=$row['PositionID']; 
}
return $PositionID;
}
// end of get_position_id_number ***************************


/********************************************************
* Function load_timezone_dropdown($saved_timezone) creates 
* a dropdown to get timezone
* The timezone format is standard (e.g. America/New_York )
* Output is dropdown with string for selected timezone
**********************************************************/
function load_timezone_dropdown($saved_timezone){
/**
// this has limited time zones - replaced with global version
    $dropdown = "<select name=crew_manager_settings[time_zone] size='1' id=crew_manager_settings[time_zone]>";

//	$dropdown ="<select name=\"crew_manager_settings[time_zone]\" id=\"crew_manager_settings[time_zone]\">";
	$dropdown .="<option value=\"Pacific/Honolulu\"";
   if ($saved_timezone=="Pacific/Honolulu") $dropdown .="selected ";
	$dropdown .=">(GMT -10:00) Hawaii (US - No DST), Honolulu</option>";
	$dropdown .="<option value=\"America/Anchorage\"";
   if ($saved_timezone=="America/Anchorage") $dropdown .="selected ";
	$dropdown .="  >(GMT -9:00) Alaska (US), Anchorage</option>";
	$dropdown .="<option value=\"America/Los_Angeles\"";
   if ($saved_timezone=="America/Los_Angeles") $dropdown .="selected ";
	$dropdown .="  >(GMT -8:00) Pacific Time (US &amp; Canada), Los Angeles</option>";
	$dropdown .="<option value=\"America/Phoenix\"";
   if ($saved_timezone=="America/Phoenix") $dropdown .="selected ";
	$dropdown .="  >(GMT -7:00) Mountain Time no DST (US &amp; Canada), Phoenix</option>";
	$dropdown .="<option value=\"America/Denver\"";
   if ($saved_timezone=="America/Denver") $dropdown .="selected ";
	$dropdown .="  >(GMT -7:00) Mountain Time (US &amp; Canada), Denver</option>";
	$dropdown .="<option value=\"America/Chicago\"";
   if ($saved_timezone=="America/Chicago") $dropdown .="selected ";
	$dropdown .="  >(GMT -6:00) Central Time (US &amp; Canada), Chicago</option>";

	$dropdown .="<option value=\"America/New_York\"";
   if ($saved_timezone=="America/New_York") $dropdown .="selected ";
	$dropdown .="  >(GMT -5:00) Eastern Time (US &amp; Canada), Newport, RI</option>";

	$dropdown .="<option value=\"America/Halifax\"";
   if ($saved_timezone=="America/Halifax") $dropdown .="selected ";
 	$dropdown .="  >(GMT -4:00) Atlantic Time (Canada), Nova Scotia</option>";

	$dropdown .="<option value=\"Canada/Newfoundland\"";
   if ($saved_timezone=="Canada/Newfoundland") $dropdown .="selected ";
	$dropdown .="  >(GMT -3:30) Newfoundland Daylight Time (Canada) Newfoundland</option>";
	$dropdown .="<option value=\"Europe/London\"";
   if ($saved_timezone=="Europe/London") $dropdown .="selected ";
	$dropdown .="  >(GMT) Western Europe Time (Europe), London</option>";
	$dropdown .="<option value=\"Europe/Brussels\"";
   if ($saved_timezone=="Europe/Brussels") $dropdown .="selected ";
	$dropdown .="   >(GMT +1:00) European Time (Europe), Madrid</option>";
	$dropdown .="</select>";
**/
// this is global version of time zone selector

$regions = array(
    'Africa' => DateTimeZone::AFRICA,
    'America' => DateTimeZone::AMERICA,
    'Antarctica' => DateTimeZone::ANTARCTICA,
    'Aisa' => DateTimeZone::ASIA,
    'Atlantic' => DateTimeZone::ATLANTIC,
    'Europe' => DateTimeZone::EUROPE,
    'Indian' => DateTimeZone::INDIAN,
    'Pacific' => DateTimeZone::PACIFIC
);
$timezones = array();
foreach ($regions as $name => $mask)
{
    $zones = DateTimeZone::listIdentifiers($mask);
    foreach($zones as $timezone)
    {
		// Lets sample the time there right now
		$time = new DateTime(NULL, new DateTimeZone($timezone));
		// Us dumb Americans can't handle millitary time
		$ampm = $time->format('H') > 12 ? ' ('. $time->format('g:ia'). ')' : '';
		// Remove region name and add a sample time
		$timezones[$name][$timezone] = substr($timezone, strlen($name) + 1) . ' - ' . $time->format('H:i') . $ampm;
	} //end foreach zones
} ////end foreach regions 
// View
    $dropdown = "<select name=crew_manager_settings[time_zone] size='1' id=crew_manager_settings[time_zone]>";
foreach($timezones as $region => $list)
{
	$dropdown .='<optgroup label="' . $region . '">' . "\n";
	foreach($list as $timezone => $name)
	{
	$name = str_replace('_', ' ', $name); // make friendly name with space
    $selected="";
    if ($saved_timezone==$timezone) $selected=" selected "; 
    $dropdown .='<option ' . $selected . 'value="' . $timezone . '">' . $name . '</option>' . "\n";

	} //end foreach list
	$dropdown .='<optgroup>' . "\n";
} //end foreach timezones
$dropdown .='</select>';

return $dropdown;
}
// end of load_timezone_dropdown ***************************


/****************************************************
 * Function load_position_text_boxes_admin() to populate
 * text boxes with crew positions to edit
 * The position descriptions are stored in table wp_crewmgr_position
 * Important values for position_id that can not be changed include
 * position = "Not Assigned" => default
 * position = "Stay Ashore" => marks displayed row in red
 * position = "Standby Crew" => marks displayed row in yellow
 *
 * Output is an array variable so that the position may be identified, and check box to mark for deletion
*****************************************************/
function load_position_text_boxes_admin()
{
global $wpdb;
    $table_crewmgr_position  = $wpdb->prefix."crewmgr_position";
$query = $wpdb->get_results("SELECT * FROM $table_crewmgr_position 
					ORDER BY position", ARRAY_A);
$dropdown="";
foreach($query as $myrow)
	{
	  if ($myrow['position']!= "Not Assigned" && $myrow['position']!=  "Stay Ashore" && $myrow['position']!= "Standby Crew" ) { 
// exclude these from editing
    $dropdown .="<br><input type='text' name='position[$myrow[position_id]]' id='position[$myrow[position_id]]' size='20' value='".$myrow['position']."'>"." Check to delete: <input type='checkbox' name='delete[$myrow[position_id]]' value='1' /> ".$myrow['position'];

	  } // endif exclude editing
	} // end foreach $query
    $dropdown .="<br><input type='text' name='newposition' id='newposition' size='20' value=''>"." <-- Type new position to be added in the text box";
return $dropdown;
}
//End function load_position_text_boxes_admin / 

/*******************************************************
 * Function load_position_action_dropdown to populate position actions dropdown box
 * 0 or null = No Input
 * 1 = Edit Position Name
 * 2 = Delete Position
 * 3 = Add New Positon
*********************************************************/
function load_position_action_dropdown()
{
    $dropdown = "<select name='action' size='1' id='action'>";
    $dropdown .= "<option value=0>-- Select Action --</option>";
    $dropdown .= "<option ";
    if ($action==1 ) $dropdown .= "selected ";
    $dropdown .= "value=1>Edit Position Name</option>";
    $dropdown .= "<option ";
    if ($action==2 ) $dropdown .= "selected ";
    $dropdown .= "value=2>Delete Position</option>";
    $dropdown .= "<option ";
    if ($action==3 ) $dropdown .= "selected ";
    $dropdown .= "value=3>Add New Position</option>";
    $dropdown .= "</select>";
return $dropdown;
}
//End function load_position_action_dropdown / 

/**************************************************************
 * Function get_multiple_users_dropdown($input_array)
 * to populate dropdown box with multiple users for selection 
 * Input is an array with previously selected users
 * Output is an array variable so that the user data may be displayed
***************************************************************/
function get_multiple_users_dropdown($input_array)
{
global $wpdb;
$query = $wpdb->get_results("SELECT u.user_login 'Logon', u.ID 'ID', u.user_email 'Email' FROM $wpdb->users as u 
ORDER BY u.user_login ", ARRAY_A);

    $dropdown = "<select name='crew[]' size='4' id='crew[]' multiple='multiple'>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["ID"] . "\"";
    $dropdown .= ">";
    $user_info = get_userdata($myrow['ID']);
    $user_firstname = $user_info->first_name;
    $user_lastname = $user_info->last_name;
    $dropdown .= $myrow["Logon"]." -> ".$user_firstname." ".$user_lastname."</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function get_multiple_users_dropdown / 

/********************************************************
 * Function get_crew_dropdown($user_ID,$indexname)
 * to populate dropdown box with registered users and
 * and index name for use in Wordpress admin arrays
 * Output is an array variable so that the user data may be displayed
*********************************************************/
function get_crew_dropdown($user_ID,$indexname)
{
global $wpdb;
if (!$indexname) $indexname="ID";
$query = $wpdb->get_results("SELECT u.user_login 'Logon', u.ID 'ID', u.user_email 'Email' FROM $wpdb->users as u 
ORDER BY u.user_login ", ARRAY_A);
$options = get_option( 'crew_manager_settings' );
    $dropdown = "<select name=crew_manager_settings[$indexname] size='1' id=crew_manager_settings[$indexname]>";
    $dropdown .= "<option value='0'>-- Select Crew --</option>";
foreach($query as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["ID"] . "\"";
    if ($user_ID==$myrow["ID"]) $dropdown .= " selected ";
    $dropdown .= ">";
    $user_info = get_userdata($myrow['ID']);
    $user_firstname = $user_info->first_name;
    $user_lastname = $user_info->last_name;
    $dropdown .= $myrow["Logon"]." -> ".$user_firstname." ".$user_lastname."</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function get_crew_dropdown / 

function crew_manager_register_settings(){
	register_setting('crew_manager_group', 'crew_manager_settings');
}
//End function crew_manager_register_settings / 

add_action('admin_init', 'crew_manager_register_settings');

/*****************************************************
* function load_all_crew_email($debug,$groupname)
* loads list of all crew members into "Email posts to subscribers" plugin
* It writes the users to the table wp_elp_emaillist (no duplicates)
* in group GetNewPosts as Confirmed
*******************************************************/
function load_all_crew_email($debug,$groupname){

if ($debug=="Yes") echo "<b>Debug Displays enabled with $"."debug set to \"Yes\"</b><br>";
if ($debug == "Yes") {
   echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Current Time UTC: ".$cur_datetime."  ".date('Y-m-d H:i:s',$cur_datetime)."<br>"; //debug
}
// first get the wp global and add prefix so existing data stored may be cleared
global $wpdb;
    $table_users  = $wpdb->prefix."users";
    $table_posts  = $wpdb->prefix."posts";
    $table_usermeta  = $wpdb->prefix."usermeta";
    $table_elp_emaillist  = $wpdb->prefix."elp_emaillist";
    $current_date = current_time( 'mysql' ); // uses Wordpress call

if ($debug=="Yes") echo "<b>Table</b> should be <b>wp_elp_emaillist</b>: ".$table_elp_emaillist."<br>";  // debug to make sure correct table is called
// Get all crew members 
$crewquery = $wpdb->get_results("SELECT u.ID 'ID' FROM $table_users u  
ORDER BY u.display_name
", ARRAY_A);

foreach($crewquery as $row)
{
	$user_id = $row['ID'];
	$user_info = $user_id ? new WP_User( $user_id ) : wp_get_current_user();
	$user_name = $user_info->first_name." ".$user_info->last_name;
	$user_email = $user_info->user_email;

	$record_check = $wpdb->get_var("SELECT COUNT(*) FROM $table_elp_emaillist
		WHERE elp_email_mail = '$user_email'
		AND elp_email_group = '$groupname';"); //record is NULL if not in database so insert
    if ($record_check == 0){
// record not found so insert new record
	if ($debug=="Yes") echo "Inserted -> " .$user_name . "  Email: ".$user_email." Status: Confirmed  Created: ".$current_date." Email Group: ".$groupname."<br>"; //debug
 //debug1 start comment out query

	    $wpdb->insert($table_elp_emaillist, array(
    	    'elp_email_name' => $user_name,
        	'elp_email_mail' => $user_email,
	        'elp_email_status' => 'Confirmed', 
    	    'elp_email_created' => $current_date,
        	'elp_email_viewcount' => 0,
	        'elp_email_group' => $groupname
    	));
 //debug1 end
    } ELSE {
// record found so ignore it
	if ($debug=="Yes") echo "-->Ignored -> " .$user_name . "  Email: ".$user_email." Created: ".$current_date."<br>"; //debug
	} // end if ($record_check == 0)
}  // end foreach($crewquery as $row)
//****** //debug turn off post status change
} // end function load_all_crew_email

/*****************************************************
* function delete_all_between($beginning, $end, $string)
* strips unwanted content between characters
* and returns the string with the content stripped
*******************************************************/
function delete_all_between($beginning, $end, $string) {
  $beginningPos = strpos($string, $beginning);
  $endPos = strpos($string, $end);
  if ($beginningPos === false || $endPos === false) {
    return $string;
  }

  $textToDelete = substr($string, $beginningPos, ($endPos + strlen($end)) - $beginningPos);

  return str_replace($textToDelete, '', $string);
}
// end function delete_all_between

/**************************************************************
 * Function load_crew_check_boxes_admin() populates check boxes
 * for all crew to setup 2 email mail lists and a retired list
 * The available lists are allposts and corecrew with the values
 * stored in the user meta table.  These may also be set on the
 * usres profile my the crew manager
 *
 * Output is an array variable so that the crew may be identified, and check boxs updated in the user meta table
***************************************************************/
function load_crew_check_boxes_admin()
{
global $wpdb;
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'first_name',
		'order' => 'ASC',
	];
	$user_query = new WP_User_Query( $user_args );
	$wp_users = $user_query->get_results();
		foreach( $wp_users as $wp_user ){
			$retired_checked = $corecrew_checked = $allposts_checked = "";
			$user_info = get_userdata( $wp_user->ID );
			$user_meta = get_user_meta( $wp_user->ID );
			if(esc_attr(get_the_author_meta( 'retired', $wp_user->ID )) == "yes") $retired_checked = "checked";
			if(esc_attr(get_the_author_meta( 'corecrew', $wp_user->ID )) == "yes") $corecrew_checked = "checked";
			if(esc_attr(get_the_author_meta( 'allposts', $wp_user->ID )) == "yes") $allposts_checked = "checked";
    $checkboxlist .="<br>Retired: <input type=\"checkbox\" name='retired[".$wp_user->ID."]' id='retired[".$wp_user->ID."]' value=\"yes\" " . $retired_checked . " />" . "  &nbsp;&nbsp;Core Crew: <input type=\"checkbox\" name='corecrew[".$wp_user->ID."]' id='corecrew[".$wp_user->ID."]' value=\"yes\" " . $corecrew_checked . " />" . "  &nbsp;&nbsp;All Posts  <input type=\"checkbox\" name='allposts[".$wp_user->ID."]' id='allposts[".$wp_user->ID."]' value=\"yes\" " . $allposts_checked . " /> <b>" . $user_info->first_name." ".$user_info->last_name ."</b>  --  ".$user_info->user_email;
	} // end foreach $query
return $checkboxlist;
}
// End function load_crew_check_boxes_admin / 

/********************************************************
* function update_crew_email_list($retired, $corecrew, $allposts)
* is called from the admin screen and stores email groups 
* allposts and corecrew as user meta data that may
* be used to selectively update email distribution
*********************************************************/
function update_crew_email_list($retired, $corecrew, $allposts){
// first get the wp global and add prefix so existing data stored may be cleared
global $wpdb;
    $table_users  = $wpdb->prefix."users";
if ($debug=="Yes") echo "<b>Table</b> should be <b>wp_elp_emaillist</b>: ".$table_elp_emaillist."<br>";  // debug to make sure correct table is called
// Get all crew members 
$crewquery = $wpdb->get_results("SELECT u.ID 'ID' FROM $table_users u
", ARRAY_A);
foreach($crewquery as $row)
{
	$user_id = $row['ID'];
	$user_info = get_userdata( $row['ID'] );
	$user_meta = get_user_meta( $row['ID'] );
	if((get_the_author_meta( 'retired', $row['ID'] ) =="yes" &&  $retired[$row['ID']] !=="yes") || (get_the_author_meta( 'retired', $row['ID'] ) !=="yes" &&  $retired[$row['ID']] =="yes") ) update_user_meta( $user_id, 'retired', $retired[$row['ID']], get_the_author_meta( 'retired', $row['ID'] ) );
	if((get_the_author_meta( 'corecrew', $row['ID'] ) =="yes" &&  $corecrew[$row['ID']] !=="yes") || (get_the_author_meta( 'corecrew', $row['ID'] ) !=="yes" &&  $corecrew[$row['ID']] =="yes") ) update_user_meta( $user_id, 'corecrew', $corecrew[$row['ID']], get_the_author_meta( 'corecrew', $row['ID'] ) );
	if((get_the_author_meta( 'allposts', $row['ID'] ) =="yes" &&  $allposts[$row['ID']] !=="yes") || (get_the_author_meta( 'allposts', $row['ID'] ) !=="yes" &&  $allposts[$row['ID']] =="yes") ) update_user_meta( $user_id, 'allposts', $allposts[$row['ID']], get_the_author_meta( 'allposts', $row['ID'] ) );
	} // end foreach($crewquery as $row)
} // end function update_crew_email_list

add_action('new_to_publish', 'send_post_email', 10, 1);
add_action('future_to_publish', 'send_post_email', 10, 1);
add_action('draft_to_publish', 'send_post_email', 10, 1);
add_action('publish_to_publish', 'transition_publish_to_publish', 10, 1);

/********************************************************
* function transition_publish_to_publish($post_id)
* is triggered by WordPress when it transitions from published to published.
* The status is passed to send_post_email
*********************************************************/
function transition_publish_to_publish($post_id){
$post = get_post($post_id);
$post_type = $post -> post_type; 
$post_title = $post -> post_title; 
	if ($post_type !=='ai1ec_event' && $post_title !=='Auto Draft') { // only process if not an ai1ec post and not an Auto Draft
	$transition_status = "anupdated";
	send_post_email($post_id, $post, $update, $transition_status);
	} // endif
}
// end function transition_publish_to_publish($post_id)

/********************************************************
* function send_post_email($post_id, $post, $update)
* is triggered by WordPress when it transitions from draft to published.
* The post is emailed using the group allposts set in the admin panel.
* The sending of emails can be turned off in the admin panel.
*********************************************************/
function send_post_email($post_id, $post, $update, $transition){
$debug = "";
$post = get_post($post_id);
$post_type = $post -> post_type; 
if ($post_type !=='ai1ec_event' && $post_type =='post' && $post_title !=='Auto Draft') { // only process if not an ai1ec post and not an Auto Draft
global $wpdb;
$transition_status = "anew";
$transition_subject_status = "New";
if ($transition) {
	$transition_status = "anupdated";
	$transition_subject_status = "Updated";
}
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'first_name',
		'order' => 'ASC',
	];
$user_query = new WP_User_Query($user_args);
$wp_users = $user_query->get_results();
$to = $recipients = "";
$i=0;
global $crew_manager_options;
$user_info = get_userdata( $crew_manager_options['skipper'] );
$from_email = $user_info->user_email;
$skipper_name = $user_info->first_name." ".$user_info->last_name;
$headers = array();
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = 'From: '.$skipper_name.' <'.$from_email.'>';
foreach( $wp_users as $wp_user )
{
	$user_id = $wp_user->ID;
	$user_info = get_userdata( $user_id );
	$user_meta = get_user_meta( $user_id );
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to_email = $user_info->user_email;
	if(get_the_author_meta( 'allposts', $user_id ) =="yes" && $post_type !== 'ai1ec_event')
		{
		//  email the post if user has allposts & not ai1ec post
	$i++;
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
	$to = $to_name. " <".$to_email.">";
$content = "Hello ###NAME###,<br><br>There is " . $transition_status . " post on the<em>[boat]</em> website.<br><br>###POSTLINK-WITHTITLE###<br><br>###POSTFULL###<br>###POSTIMAGE###";
$subject = "[boat] " . $transition_subject_status ." Post: ###POSTTITLE###";
global $crew_manager_options;
if($crew_manager_options['stop_crew_email']==1)	send_formatted_email($user_id, $subject, $content, $post_id);
		} // endif get_the_author_meta( 'allposts', $row['ID']
	} // end foreach( $wp_users as $wp_user )
$subject = "[boat] Post Sent: ###POSTTITLE###";
$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "A post was sent to " . $i . $emails . ". Please find the details below<br><br>";
if($crew_manager_options['stop_elp_notifications']==1) send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
} // endif ($post_type !=='ai1ec_event') 

}// end send_post_email

/********************************************************
* function send_formatted_email($user_id, $subject, $content, $post_id)
* gets input from the various routines that passes initial content for 
* email formattted in this routine for posts and events.  
* It handles a single message and recipient at a time.
* It is not called if sending crew emails is turned off in the admin panel.
*********************************************************/
function send_formatted_email($user_id, $subject, $content, $post_id){
					$post = get_post($post_id);
if (!session_id())  session_start();  // allows saving variables between page submissions
$_SESSION['elp_post_id'] = $post_id; // passes to [crew] for processing	

	$user_info = get_userdata( $user_id );
	$to_email = $user_info->user_email;
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to = $to_name. " <".$to_email.">";
						$content = stripslashes($content);
						$content = do_shortcode($content); //process shortcodes
						$subject = do_shortcode($subject); //process shortcodes
						$subject =  str_replace("###POSTTITLE###", do_shortcode($post->post_title), $subject); //process shortcodes
						$subject =  str_replace("&amp;", "&", $subject); // puts "&" in for ascii code

							$content = str_replace("\r\n", "<br />", $content);
							$content = str_replace("###NAME###", $to_name, $content);
							$content = str_replace("###POSTTITLE###", do_shortcode($post->post_title), $content); // process shortcodes
							$post_content_no_html = apply_filters('the_content', do_shortcode($post->post_content));  // process shortcodes and keep formatting with wp filters
							$post_content_no_html = delete_all_between("<select", "select>", $post_content_no_html); // strips select availability button
							$post_content_no_html = delete_all_between("<input", 'Change">', $post_content_no_html); // strips submit button
							$post_content_no_html = delete_all_between("<input", 'Immediately">', $post_content_no_html); // strips cancel event button
							$post_content_no_html = delete_all_between('<div', '/div>', $post_content_no_html); // strips login button url
							$content = str_replace("###POSTFULL###", $post_content_no_html, $content);
							$post_link = get_permalink($post_id);
							$post_link_with_title = "<a href='".$post_link."' target='_blank'>".do_shortcode($post->post_title)."</a>"; // process shortcodes
							$content = str_replace("###POSTLINK###", $post_link, $content);
							$content = str_replace("###POSTLINK-ONLY###", $post_link, $content);
							$content = str_replace("###POSTLINK-WITHTITLE###", $post_link_with_title, $content);
							$post_thumbnail = "";
							if ( (function_exists('has_post_thumbnail')) && (has_post_thumbnail($post_id)) ) {
								$post_thumbnail = get_the_post_thumbnail( $post_id, 'medium' );
							}
							$post_thumbnail_link = "";
							if($post_thumbnail <> "") {
								$post_thumbnail_link = "<a href='".$post_link."' target='_blank'>".$post_thumbnail."</a>";
							}
							$content = str_replace("###POSTIMAGE###", $post_thumbnail_link, $content);
							if(strlen($post->post_modified) > 10) {
								$post_modified = substr($post->post_modified, 0, 10);
							}
							else {
								$post_modified = "";
							}
							$content = str_replace("###DATE###", $post_modified, $content);
global $crew_manager_options;
$user_info = get_userdata( $crew_manager_options['skipper'] );
$from_email = $user_info->user_email;
$skipper_name = $user_info->first_name." ".$user_info->last_name;
$headers = array();
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = 'From: '.$skipper_name.' <'.$from_email.'>';
wp_mail($to, $subject, $content, $headers);
}// end send_formatted_email

/********************************************************
* function send_notification_email($subject, $content, $recipients, $post_id)
* $post_id = 0 means it was a skipper generated email
* gets input from the various routines that provide content for 
* email after sending messages to the crew.  
* It is not called if sending admin emails is turned off in the admin panel.
*********************************************************/
function send_notification_email($subject, $content, $recipients, $post_id){
global $crew_manager_options;
if ($post_id!==0) $post = get_post($post_id);
$subject = do_shortcode($subject); //process shortcodes
$subject =  str_replace("###POSTTITLE###", "", $subject); //process shortcodes
$subject =  str_replace("&amp;", "&", $subject); // puts "&" in for ascii code
// below is where we get the crew admin and 2nd crew admin name & emails if defined in admin panel
$user_info = get_userdata( $crew_manager_options['skipper'] );
$user_info = $crew_manager_options['skipper'] ? new WP_User( $crew_manager_options['skipper'] ) : wp_get_current_user();
$crew_administrators = $user_info->first_name." ".$user_info->last_name. " <".$user_info->user_email.">"; // admin for email notification defined in admin panel
if (!$crew_manager_options['skipper_admin']==0) { // gets 2nd admin if set in admin panel
$crew_administrators .=", ";
$user_info = get_userdata( $crew_manager_options['skipper'] );
$user_info = $crew_manager_options['skipper_admin'] ? new WP_User( $crew_manager_options['skipper_admin'] ) : wp_get_current_user();
$crew_administrators .= $user_info->first_name." ".$user_info->last_name. " <".$user_info->user_email.">"; // adds second admin for email notification if defined in admin panel
} // endif (!$crew_manager_options['skipper_admin']==0) gets 2nd admin email
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
$cur_datetime = strtotime(date("Y-m-d H:i:s")); // gets curent datetime for query
if ($post_id!==0) $post_link = get_permalink($post_id);
$post_subject = $subject;
if ($post_id!==0) $post_subject = $subject . " <a href='".$post_link."' target='_blank'>".do_shortcode($post->post_title)."</a>";
$notification_email = $content;
$notification_email .= "<b>Subject:</b> " . $post_subject;
$notification_email .= "<br><be><b>Email send time completion:</b> " . date('D F jS, Y @ g:i:sa T',$cur_datetime) . "<br>";
$notification_email .= "<b>Recipients:</b><br>" . $recipients;
$user_info = get_userdata( $crew_manager_options['skipper'] );
$from_email = $user_info->user_email;
$skipper_name = $user_info->first_name." ".$user_info->last_name;
$headers = array();
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = 'From: Crew Manager Administrator  <' .  get_bloginfo("admin_email") .'>';
if ($notification_email && $crew_manager_options['stop_crew_email']==1) wp_mail($crew_administrators, get_bloginfo() . " Email Sent Report", $notification_email, $headers); // sends the email report
}// end send_notification_email

/***************************
* function  crew_manager_send_comment($comment_id, $comment_approved)
* This function is trigger on comment posted and emails the comment. 
* If it is an ai1ec event comment, it goes to the event crew.
* If it is a post, it goes to the AllCrew list.
* 
****************************/
 add_action( 'comment_post', 'crew_manager_send_comment', 10, 2);
function crew_manager_send_comment($comment_id, $comment_approved )
{
// first get the fields we want with the comment data
	$posted_comment = get_comment( $comment_id );
	$name = $posted_comment->comment_author;
	$user_id = $posted_comment->user_id;
	$post_id = $posted_comment->comment_post_ID;
	$comment_content = $posted_comment->comment_content;
	$comment_date = $posted_comment->comment_date;
	$comment_parent = $posted_comment->comment_parent;
	$author_email = $posted_comment->comment_author_email;
// now format the email content based on a post or ai1ec event
$content_post = get_post($post_id);
$Event_URL='<a href="'.get_permalink( $post_id ).'">'.do_shortcode(get_the_title( $post_id )).'</a>';
global $crew_manager_options;
$user_info = get_userdata( $crew_manager_options['skipper'] );
$from_email = $user_info->user_email;
$skipper_name = $user_info->first_name." ".$user_info->last_name;
$headers = array();
$headers[] = 'Content-Type: text/html; charset=UTF-8';
$headers[] = 'From: '.$skipper_name.' <'.$from_email.'>';
$tz = $crew_manager_options['time_zone'];
date_default_timezone_set($tz); //Corrects for local
$content = $name . " made the following comment on " . date('D F jS, Y @ g:ia T',strtotime(date("Y-m-d H:i:s"))) . " in response to: " . $Event_URL . "<br><br>";
$content .= $comment_content . "<br><br>";
$content .= do_shortcode("If you would like to respond, click on the link above and submit your reply.  You must be logged in to the [boat] website.<br>");
$subject = do_shortcode("[boat] Comment Posted: " . do_shortcode(get_the_title( $post_id )));
$post_type = $content_post -> post_type;
	if ($post_type !=='ai1ec_event')
	{ // format output for post comment


global $wpdb;
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'first_name',
		'order' => 'ASC',
	];
$user_query = new WP_User_Query($user_args);
$wp_users = $user_query->get_results();
$to = $recipients = "";
$i=0;
foreach( $wp_users as $wp_user )
{
	$user_id = $wp_user->ID;
	$user_info = get_userdata( $user_id );
	$user_meta = get_user_meta( $user_id );
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to_email = $user_info->user_email;
		if(get_the_author_meta( 'allposts', $user_id ) =="yes")
		{
		//  email the post if user has allposts checked
			$i++;
			$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
			$to = $to_name. " <".$to_email.">";
			global $crew_manager_options;
			if($crew_manager_options['stop_crew_email']==1)	wp_mail($to, $subject, $content, $headers); // execute the send routine
		} // endif get_the_author_meta( 'allposts', $row['ID']
	} // end foreach( $wp_users as $wp_user )
$subject = do_shortcode("[boat] Comment Posted: ###POSTTITLE###");
$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "A post comment was sent to " . $i . $emails . ". Please find the details below<br><br>";
if($crew_manager_options['stop_elp_notifications']==1) send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
	} else 
	{ // format output for ai1ec_event comment
$subject = do_shortcode("[boat] Event Comment Posted: " . get_the_title( $post_id ));

// Get crew members for selected post
// exclude not available and show available if position designated as 'Stay Ashore'
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_users  = $wpdb->prefix."users";
$crewquery = $wpdb->get_results("SELECT `u`.ID 'ID', `cma`.available 'Available'  FROM `$table_ai1ec_events` `e`, `$table_crewmgr_assigned` `cma`, `$table_users` `u`  
WHERE `e`.post_id = '$post_id' AND `cma`.ai1ec_post_id = '$post_id'
AND `u`.ID = `cma`.user_ID
AND `cma`.available < 3
ORDER BY `cma`.available, `u`.display_name
", ARRAY_A);

$i=0; // initialize number of messages sent counter
foreach($crewquery as $row)
{
	$i++;
	$user_id = $row['ID'];
	$user_info = get_userdata( $user_id );
	$to_email = $user_info->user_email;
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to = $to_name. " <".$to_email.">";
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
	if($crew_manager_options['stop_crew_email']==1)	wp_mail($to, $subject, $content, $headers); // execute the send routine
} // end foreach($crewquery as $row)

$subject = do_shortcode("[boat] Event Comment Posted: ###POSTTITLE###");
$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "An event comment was sent to " . $i . $emails . ". Please find the details below<br><br>";
if($crew_manager_options['stop_elp_notifications']==1) send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
	} // end if ($post_type =='ai1ec_event')
} // end function crew_manager_send_comment

/***************************
* function  cancel_event($post_id)
* This function is is triggred by button for skipper in [crew]. 
* It immediately cancels the event and notifies the crew
* 1. Check if event already canceled, exit if it is
* 2. Prefix post title with "Canceled: "
* 3. Prefix post content with "<h2>Event Canceled</h2>"
* 4. Send participant email (use query from get_eventcrew_crontask.php)
* 5. Send notification email to admins, if enabled
****************************/
function cancel_event($post_id)
{
$post = get_post($post_id);
$post_title = $post->post_title;
if (stripos($post_title, "anceled:") === false) {
// checked if already canceled so now must do updates since it was not
$screen_message = "<div style=\"font-size: 150%; text-align: center; font-family: sans-serif\"><p style=\"color: #ff0000; background-color: #ffffff \"><b>Event was Canceled & email notifications sent<br>Refreshing Display</b></p></div>";
$post_content = $post->post_content; 
// Update post by setting elements in an array
  $canceled_post = array(
      'ID'           => $post_id,
      'post_title'   => 'Canceled: ' . $post_title,
      'post_content' => '<h3>This event is canceled</h3>' . $post_content,
  );

// Update the post into the database
  wp_update_post( $canceled_post );
// Get crew members for selected post
// exclude not available and show available if position designated as 'Stay Ashore'
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_users  = $wpdb->prefix."users";

$crewquery = $wpdb->get_results("SELECT `u`.ID 'ID', `cma`.available 'Available'  FROM `$table_ai1ec_events` `e`, `$table_crewmgr_assigned` `cma`, `$table_users` `u`  
WHERE `e`.post_id = '$post_id' AND `cma`.ai1ec_post_id = '$post_id'
AND `u`.ID = `cma`.user_ID
AND `cma`.available < 3
ORDER BY `cma`.available, `u`.display_name
", ARRAY_A);

$event_date = get_event_start_date($post_id);
$i=0; // initialize number of messages sent counter
$subject = "[boat] Event ###POSTTITLE### " . $event_date;
$content = "Hello ###NAME###,<br><br><h2>The following event is canceled</h2><br>###POSTLINK-WITHTITLE###<br><br>###POSTFULL###<br>###POSTIMAGE###"; 
foreach($crewquery as $row)
{
	$i++;
	$user_id = $row['ID'];
	$user_info = get_userdata( $user_id );
	$to_email = $user_info->user_email;
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to = $to_name. " <".$to_email.">";
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
	send_formatted_email($user_id, $subject, $content, $post_id); // execute the send routine
} // end foreach($crewquery as $row)
if ($debug=="Yes") echo  $recipients . "<br>"; // debug
if ($debug=="Yes") echo "Post ID processed: ".$post_id."<br>"; // debug
global $crew_manager_options;
$subject_to_crew = $subject;
$subject = "[boat] Event " . $post_title . " " . $event_date;
$emails = " email address";
if ($i >= 2) $emails = " email addresses";
$content = "An event cancellation was sent successfully to " . $i . $emails . ". Please find the details below<br><br>";
if($crew_manager_options['stop_elp_notifications']==1) send_notification_email($subject, $content, $recipients, $post_id); // sends delivery report to admins
} // end if (stripos($post_title, "Canceled:")
$_POST['screen_message'] = $screen_message;
// return $_POST['screen_message'];
} // end function cancel_event($post_id)


/********************************************************
 * Function get_to_group_dropdown()
 * to populate dropdown box with groups for skipper to email.
 * The first two groups are Core Crew and All Posts set in Admin screen.
 * The other groups are Crew listed for a particlar AI1EC event
*********************************************************/
function get_to_group_dropdown()
{
$cur_yr = date('Y'); // gets curent year for query
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_ai1ec_instances  = $wpdb->prefix."ai1ec_event_instances";
    $table_posts  = $wpdb->prefix."posts";
$eventquery = $wpdb->get_results("SELECT DISTINCT e.start 'Start', e.end 'End', e.venue 'Location', p.post_title 'Event', p.ID 'PostID' FROM $table_ai1ec_events e, $table_ai1ec_instances i, $table_posts p 
WHERE e.post_id = p.ID
AND e.post_id = i.post_id
AND p.post_status = 'publish'

AND FROM_UNIXTIME(e.start, '%Y') = $cur_yr
GROUP BY p.ID
ORDER BY e.start
", ARRAY_A);

    $dropdown = "<select name=to_group size='1' id=to_group>";
    $dropdown .= "<option value='0'>-- Select Email Group to Send Message--</option>";
    $dropdown .= "<option value='1'>Core Crew Email Group</option>";
    $dropdown .= "<option value='2'>All Posts Email Group</option>";
foreach($eventquery as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["PostID"] . "\"";
//    if ($user_ID==$myrow["ID"]) $dropdown .= " selected ";
    $dropdown .= ">";
	$tz = $crew_manager_options['time_zone'];
	date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D, M jS", $myrow['Start']);
     $event_time=date("g:i A", $myrow['Start']);
    $dropdown .= "Crew Assigned to - " . $myrow["Event"]." (".$event_date." ".$event_time.")</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function get_to_group_dropdown / 


/********************************************************
 * Function get_email_for_post($post_id)
 * gets crew associated with an ai1ec post and writes 
 * to an array for processing formated as First_name Last_name <email>.
 * exclude not available and show available if position designated as 
 * 'Stay Ashore'.  Also returns group_recipients to email group,
 * count of recipients and recipients for skipper status message
 * all in the returned array called $email_array
*********************************************************/
function get_email_for_post($post_id)
{
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_crewmgr_assigned  = $wpdb->prefix."crewmgr_assigned";
    $table_users  = $wpdb->prefix."users";
    $table_posts  = $wpdb->prefix."posts";
$crewquery = $wpdb->get_results("SELECT `u`.ID 'ID', `cma`.available 'Available'  FROM `$table_ai1ec_events` `e`, `$table_crewmgr_assigned` `cma`, `$table_users` `u`  
WHERE `e`.post_id = '$post_id' AND `cma`.ai1ec_post_id = '$post_id'
AND `u`.ID = `cma`.user_ID
AND `cma`.available < 3
ORDER BY `cma`.available, `u`.display_name
", ARRAY_A);
$email_array = array(); // initialize email array
$to = $to_group = $recipients = "";
$i=0; // initialize number of messages sent counter
foreach($crewquery as $row)
{
// var_dump($row); // debug
	$i++;
	$user_id = $row['ID'];
	$user_info = get_userdata( $user_id );
	$to_email = $user_info->user_email;
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to = $to_name. " <".$to_email.">";
	$to_group .=$to_name. " <".$to_email.">, ";
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
     $email_array[] = array('formatted_email' => $to);
} // end foreach($crewquery as $row)
$email_array[] = array('group_recipients' => $to_group);
$email_array[] = array('recipients' => $recipients);
$email_array[] = array('number_recipients' => $i);
return $email_array;
}
//End function get_email_for_post($post_id) 

/********************************************************
 * function get_email_for_group($group)
 * where $group is a string with the group name 'core_crew'
 * or 'allposts'
 * gets crew associated with a defined group and writes 
 * to an array for processing formated as First_name Last_name <email>.
 * Also returns group_recipients to email group,
 * count of recipients and recipients for skipper status message
 * all in the returned array called $email_array
*********************************************************/
function get_email_for_group($group){
global $wpdb;
 // Adjust the query arguments here if need be.
	$user_args = [
		'orderby' => 'first_name',
		'order' => 'ASC',
	];
$user_query = new WP_User_Query($user_args);
$wp_users = $user_query->get_results();
$to = $to_group = $recipients = "";
$i=0;
foreach( $wp_users as $wp_user )
{
	$user_id = $wp_user->ID;
	$user_info = get_userdata( $user_id );
	$user_meta = get_user_meta( $user_id );
	$to_name = $user_info->first_name." ".$user_info->last_name;
	$to_email = $user_info->user_email;
	if(get_the_author_meta( $group, $user_id ) =="yes")
		{
		//  email the post if user has allposts & not ai1ec post
	$i++;
	$recipients .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;" . $to_name . " [" . $to_email . "]<br>";
	$to = $to_name. " <".$to_email.">";
	$to_group .=$to_name. " <".$to_email.">, ";
    $email_array[] = array('formatted_email' => $to);
		} // endif get_the_author_meta( 'allposts', $row['ID']
	} // end foreach( $wp_users as $wp_user )
$email_array[] = array('group_recipients' => $to_group);
$email_array[] = array('recipients' => $recipients);
$email_array[] = array('number_recipients' => $i);
return $email_array;
}// end function get_email_for_group($group)


/********************************************************
 * Function get_regatta_dropdown($post_id)
 * to populate dropdown box with regatta for skipper to run report.
 * The selected event provides a post ID
*********************************************************/
function get_regatta_dropdown($post_id)
{
$cur_yr = date('Y'); // gets curent year for query
// Get the data from the ai1ec_events table in the Wordpress database.
global $wpdb;
    $table_ai1ec_events  = $wpdb->prefix."ai1ec_events";
    $table_ai1ec_instances  = $wpdb->prefix."ai1ec_event_instances";
    $table_posts  = $wpdb->prefix."posts";
$eventquery = $wpdb->get_results("SELECT DISTINCT e.start 'Start', e.end 'End', e.venue 'Location', p.post_title 'Event', p.ID 'PostID' FROM $table_ai1ec_events e, $table_ai1ec_instances i, $table_posts p 
WHERE e.post_id = p.ID
AND e.post_id = i.post_id
AND p.post_status = 'publish'

AND FROM_UNIXTIME(e.start, '%Y') = $cur_yr
GROUP BY p.ID
ORDER BY e.start
", ARRAY_A);

    $dropdown = "<select name=regatta size='1' id=regatta>";
    $dropdown .= "<option value='0'>-- Select Regatta for Report --</option>";
foreach($eventquery as $myrow)
	{
    $dropdown .= "<option value=\"". $myrow["PostID"] . "\"";
    if ($post_id==$myrow["PostID"]) $dropdown .= " selected ";
    $dropdown .= ">";
	$tz = $crew_manager_options['time_zone'];
	date_default_timezone_set($tz); //Corrects for local
     $event_date=date("D, M jS", $myrow['Start']);
     $event_time=date("g:i A", $myrow['Start']);
    $dropdown .= $myrow["Event"]." (".$event_date." ".$event_time.")</option>";
	}
    $dropdown .= "</select>";
return $dropdown;
}
//End function get_regatta_dropdown / 


